@@ -9,6 +9,10 @@
 
 #include <sigc++/sigc++.h>
 
+SIGC_USING_STD(cout)
+SIGC_USING_STD(endl)
+SIGC_USING_STD(string)
+
 class Something : public sigc::trackable
 {
 public:
@@ -39,7 +43,8 @@ void Something::on_print(int a)
   std::cout << "on_print recieved: " << a << std::endl;
 }
 
-main()
+int main()
 {
   Something something;  
+  return 0;
 }
